@@ -18,29 +18,24 @@ colorama.init(autoreset=True)
 
 class Logger:
     def __init__(self, name, level=logging.DEBUG):
-        logging.basicConfig(format='%(asctime)s %(message)-10s ',
-                            datefmt='%Y/%m/%d %H:%M:%S')
+        logging.basicConfig(
+            format="%(asctime)s %(message)-10s ", datefmt="%Y/%m/%d %H:%M:%S"
+        )
 
         self.logger = logging.getLogger(name)
         self.logger.setLevel(level)
 
-    def debug(self, message):
-        self.logger.debug(message)
-
     def info(self, color, type, message):
-        self.logger.info(color + '[%-8s] %-2s %s' % (type, 'OK', message) + Style.RESET_ALL)
-
-    def warning(self, message):
-        self.logger.info(message)
+        self.logger.info(
+            color + "[%-8s] %-2s %s" % (type, "OK", message) + Style.RESET_ALL
+        )
 
     def error(self, type, message):
-        self.logger.error(Fore.RED + '[%-8s] %-4s %s' % (type, 'FAIL', message) + Style.RESET_ALL)
-
-    def critical(self, message):
-        self.logger.info(message)
-
-    def exception(self, type, message):
-        self.logger.error(Fore.RED + '[%-8s] %-4s %s' % (type, 'FAIL', message) + Style.RESET_ALL)
+        self.logger.error(
+            Fore.RED
+            + "[%-8s] %-4s %s" % (type, "FAIL", message)
+            + Style.RESET_ALL
+        )
 
 
 logger = Logger(__name__)
